==> react-awesome-snippets-bgm-0.0.4.tgz: package/BGM.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var BGM = function (_Component) {
    _inherits(BGM, _Component);

    function BGM() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, BGM);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = BGM.__proto__ || Object.getPrototypeOf(BGM)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
            playing: true
        }, _this.onpause = function () {
            return _this.setState({
                playing: false
            }, _this.props.onpause);
        }, _this.onplay = function () {
            return _this.setState({
                playing: true
            }, _this.props.onplay);
        }, _this.playInWeixin = function () {
            window.WeixinJSBridge.invoke('getNetworkType', {}, function (e) {
                _this.player.play();
            });
        }, _this.playInWeibo = function () {
            window.WeiboJSBridge.invoke('getNetworkType', {}, function (e) {
                _this.player.play();
            });
        }, _this.autoplay = function (ev) {
            var player = _this.refs.player;

            if (!_this.userClick && //用户没有操作过
            player.paused //且没有在播放
            ) {
                    player.play();
                }

            if (ev && ev.type === 'touchstart') {
                //移除事件绑定
                document.removeEventListener('touchstart', _this.autoplay, false);
            }
        }, _this.togglePlay = function () {
            var player = _this.refs.player;

            _this.userClick = true; //标示用户已操作过

            player.paused ? player.play() : player.pause();
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(BGM, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            if (this.props.autoplay && this.refs.player.paused) {
                //支持微信、微博下自动播放
                if (typeof WeixinJSBridge !== 'undefined') {
                    this.playInWeixin();
                } else {
                    document.addEventListener('WeixinJSBridgeReady', this.playInWeixin, false);
                }

                if (typeof WeiboJSBridge !== 'undefined') {
                    this.playInWeibo();
                } else {
                    document.addEventListener('WeiboJSBridgeReady', this.playInWeibo, false);
                }

                document.addEventListener('touchstart', this.autoplay, false);
            }

            this.refs.box.addEventListener('click', this.togglePlay, false);
            this.refs.player.addEventListener('pause', this.onpause, false);
            this.refs.player.addEventListener('play', this.onplay, false);
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.refs.box.removeEventListener('click', this.togglePlay, false);
            this.refs.player.addEventListener('pause', this.onpause, false);
            this.refs.player.addEventListener('play', this.onplay, false);

            if (this.props.autoplay) {
                document.removeEventListener('touchstart', this.autoplay, false);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var playing = this.state.playing;
            var _props = this.props,
                className = _props.className,
                autoplay = _props.autoplay,
                loop = _props.loop,
                component = _props.component;

            var children = component || this.props.children;

            if (typeof children === 'function') {
                var Children = children;

                children = React.createElement(Children, { playing: playing, paused: !playing });
            }

            return React.createElement(
                'div',
                {
                    className: (className ? className + ' ' : '') + 'bgm-box ' + (this.state.playing ? 'bgm-playing' : 'bgm-paused'),
                    ref: 'box' },
                React.createElement('audio', { autoPlay: autoplay, loop: loop, src: this.props.src, className: 'player', ref: 'player' }),
                children || React.createElement('div', { className: 'music' })
            );
        }
    }]);

    return BGM;
}(Component);

BGM.defaultProps = {
    autoplay: true,
    loop: true
};
BGM.propTypes = {
    src: PropTypes.string.isRequired,
    autoplay: PropTypes.bool,
    loop: PropTypes.bool,
    onplay: PropTypes.func,
    onpause: PropTypes.func,
    component: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
    children: PropTypes.oneOfType([PropTypes.node, PropTypes.func])
};


export default BGM;

==> react-awesome-snippets-bgm-0.0.5.tgz: package/BGM.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var BGM = function (_Component) {
    _inherits(BGM, _Component);

    function BGM() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, BGM);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = BGM.__proto__ || Object.getPrototypeOf(BGM)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
            playing: true
        }, _this.onpause = function () {
            return _this.setState({
                playing: false
            }, _this.props.onpause);
        }, _this.onplay = function () {
            return _this.setState({
                playing: true
            }, _this.props.onplay);
        }, _this.autoplay = function (ev) {
            var player = _this.refs.player;

            if (!_this.userClicked && player.paused) {
                if (typeof WeixinJSBridge !== 'undefined') {
                    window.WeixinJSBridge.invoke('getNetworkType', {}, function (e) {
                        player.play();
                    });
                } else if (typeof WeiboJSBridge !== 'undefined') {
                    window.WeiboJSBridge.invoke('getNetworkType', {}, function (e) {
                        player.play();
                    });
                } else {
                    player.play(); //尝试直接播放

                    //依然无法播放
                    if (player.paused) {
                        document.addEventListener('touchstart', _this.autoplay, false);
                        document.addEventListener('WeixinJSBridgeReady', _this.autoplay, false);
                        document.addEventListener('WeiboJSBridgeReady', _this.autoplay, false);
                    }
                }
            }

            if (ev && ev.type === 'touchstart') {
                //移除事件绑定
                document.removeEventListener('touchstart', _this.autoplay, false);
            }
        }, _this.togglePlay = function () {
            var player = _this.refs.player;

            _this.userClicked = true; //标示用户已操作过

            player.paused ? player.play() : player.pause();
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(BGM, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.refs.box.addEventListener('click', this.togglePlay, false);
            this.refs.player.addEventListener('pause', this.onpause, false);
            this.refs.player.addEventListener('play', this.onplay, false);

            if (this.props.autoplay) {
                this.autoplay();
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.refs.box.removeEventListener('click', this.togglePlay, false);
            this.refs.player.addEventListener('pause', this.onpause, false);
            this.refs.player.addEventListener('play', this.onplay, false);

            if (this.props.autoplay) {
                document.removeEventListener('touchstart', this.autoplay, false);
                document.removeEventListener('WeixinJSBridgeReady', this.autoplay, false);
                document.removeEventListener('WeiboJSBridgeReady', this.autoplay, false);
            }
        }

        //支持微信、微博下自动播放

    }, {
        key: 'render',
        value: function render() {
            var playing = this.state.playing;
            var _props = this.props,
                className = _props.className,
                autoplay = _props.autoplay,
                loop = _props.loop,
                component = _props.component;

            var children = component || this.props.children;

            if (typeof children === 'function') {
                var Children = children;

                children = React.createElement(Children, { playing: playing, paused: !playing });
            }

            return React.createElement(
                'div',
                {
                    className: (className ? className + ' ' : '') + 'bgm-box ' + (this.state.playing ? 'bgm-playing' : 'bgm-paused'),
                    ref: 'box' },
                React.createElement('audio', { autoPlay: autoplay, loop: loop, src: this.props.src, className: 'player', ref: 'player' }),
                children || React.createElement('div', { className: 'music' })
            );
        }
    }]);

    return BGM;
}(Component);

BGM.defaultProps = {
    autoplay: true,
    loop: true
};
BGM.propTypes = {
    src: PropTypes.string.isRequired,
    autoplay: PropTypes.bool,
    loop: PropTypes.bool,
    onplay: PropTypes.func,
    onpause: PropTypes.func,
    component: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
    children: PropTypes.oneOfType([PropTypes.node, PropTypes.func])
};


export default BGM;
